/*
  layeredwidget.h
  Copyright (C) 2008 Tomohiro Masubuchi <bucchi@e-ml.jp>

  This file is part of qgmap.

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef __LAYEREDWIDGET_H__
#define __LAYEREDWIDGET_H__

#include <qwidget.h>
#include <qobject.h>
#include <qpainter.h>

class LayeredBase;

class LayeredWidget : public QObject
{
  public:
	LayeredWidget( LayeredBase *parent = 0, const char *name = 0);

	void setGeometry(const QRect &);
	void setGeometry(int, int, int, int);
	const QRect &geometry();
	int x();
	int y();
	int width();
	int height();
	QPoint pos();
	QSize size();
	void resize(int w, int h);
	void resize(QSize const & size);

	virtual bool paintEvent( QPixmap &p );
	virtual void showEvent();
	virtual bool keyPressEvent(QKeyEvent *e);
	virtual bool keyReleaseEvent(QKeyEvent *e);
	virtual bool wheelEvent(QWheelEvent *e);
	virtual bool mousePressEvent(QMouseEvent *e);
	virtual bool mouseReleaseEvent(QMouseEvent *e);
	virtual bool mouseMoveEvent(QMouseEvent *e);

	LayeredBase *parentWidget();

	void repaint();

  private:
	QRect widget_position;
	LayeredBase *parent_widget;
};

#endif // __LAYEREDWIDGET_H__
